signers_id

Function signers_id 

pub fn signers_id(account_id: &AccountID) -> Result<LedgerEntryIdBytes>
Generates a signer entry ledger entry ID for a given XRP Ledger account.

signer entry ledger entry IDs are used to reference signer entries in the XRP Ledger’s state data. This function uses the generic create_id_from_host_call helper to manage the FFI interaction.

Arguments

  • account_id - Reference to an AccountID representing the XRP Ledger account

Returns

  • Result<LedgerEntryIdBytes> - On success, returns a 32-byte signer entry ledger entry ID. On failure, returns an Error with the corresponding error code.

Safety

This function makes unsafe FFI calls to the host environment through the host::signers_id function, though the unsafe code is contained within the closure passed to create_id_from_host_call.

Example


use xrpl_common_stdlib::types::account_id::AccountID;
use xrpl_common_stdlib::ledger_entry_ids::signers_id;
use xrpl_common_stdlib::host::trace::{ trace_hex, trace_num };
fn main() -> Result<(), Box<dyn std::error::Error>> {
  let account:AccountID = AccountID::from(
    *b"\xd5\xb9\x84VP\x9f \xb5'\x9d\x1eJ.\xe8\xb2\xaa\x82\xaec\xe3"
  );
  match signers_id(&account){
    xrpl_common_stdlib::host::Result::Ok(id) => {
      trace_hex("Generated ledger entry ID", &id);
    }
    xrpl_common_stdlib::host::Result::Err(e) => {
      trace_num("Error assembling ledger entry ID", e.code() as i64);
    }
  }
  Ok(())
}